import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_athena._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_glue._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kinesisfirehose._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_notifications._jsii
import aws_cdk.aws_wafv2._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@ikala-cloud/aws-waf-solution",
    "1.0.18",
    __name__[0:-6],
    "aws-waf-solution@1.0.18.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
